" Vim syntax file
" Language:	Microchip PIC Assembler (simplistic implementation)
" Maintainer:   Alan Robert Clark <clark@YingTongDiddleiPo.ee.wits.ac.za>
" Last change:  1999 Jan 24

" Heavily adapted from The GNU Assembler syntax files of:
" Maintainer:	Kevin Dahlhausen <ap096@po.cwru.edu>
" Last change:	1997 April 20

" Remove any old syntax stuff hanging around
syn clear

syn case ignore

" Various #'s as defined by GAS ref manual sec 3.6.2.1
" Technically, the first decNumber def is actually octal,
" since the value of 0-7 octal is the same as 0-7 decimal,
" I prefer to map it as decimal:
syn match decNumber		"0\+[1-7]\=[\t\n$,; ]"
syn match decNumber		"[1-9][0-9]*"
syn match octNumber		"0[0-7][0-7]\+"
syn match hexNumber		"0[xX][0-9a-fA-F]\+"
syn match binNumber		"0[bB][0-1]*"

syn match picComment		";.*"
syn region picString            start=+"+ end=+"+ skip=+\\"+

syn keyword picDirective        list org include 
syn keyword picByteReg          addwf andwf clrf clrw comf decf
syn keyword picByteReg          incf iorwf movf movwf nop rlf 
syn keyword picByteReg          rrf subwf swapf xorwf
syn keyword picBitReg           bcf bsf 
syn keyword picBranch           decfsz incfsz btfsc btfss goto call 
syn keyword picLiteral          addlw andlw iorlw movlw retlw sublw xorlw
syn keyword picControl          clrwdt retfie return sleep 

syn case match

" The default methods for highlighting.  Can be overridden later
" ARC: Effectively there are 6 different types only! Hence the 
" names are a bit odd, but better than the contrived links that 
" all come back to these names anyway!
hi link picComment    Comment
hi link picDirective  PreProc 
hi link picByteReg    Identifier
hi link picBitReg     Identifier
hi link picBranch     Statement
hi link picLiteral    Type
hi link picControl    Statement
hi link picString     Number
hi link hexNumber     Number
hi link decNumber     Number
hi link octNumber     Number
hi link binNumber     Number

let b:current_syntax = "pic"

" vim: ts=8
